NML documentation

# Airports and airport tiles

## Airport properties

name | value range | comment
--- | --- | ---
name | string | Name of the airport
override |  | the id of airport to replace / override
layouts | list of layouts |
years_available | [start year, last year] | list of the availablility years: first and last year it can be built
ttd_airport-type | 0 ... 3 | substitute TTDPatch airport type
catchment_area |  | catchment area of the airport in tiles around its perimeter
noise_level |  | noise generation of this airport

## Airport tile properties

name | value range | comment
--- | --- | ---
override |  | the id of airport tile to override
substitute |  | the id of airport tile to replace
callback_flags | bitmask |
animation_info |  |
animation_speed |  | see speed settings
animation_triggers |  |

## Airport variables

name | value range | comment
--- | --- | ---
layout | 0 .. (number of layouts - 1) | Layout number of the airport (index in the layouts array)

## Airport tile variables

name | value range | comment
--- | --- | ---
terrain_type |  |
town_radius_group |  |
relative_x | 0..255 | X-coordinate (top right -> bottom left) of the tile relative to the northernmost tile.
relative_y | 0..255 | Y-coordinate (top left -> bottom right) of the tile relative to the northernmost tile.
relative_pos | 0xYYXX | A combination of relative_x and relative_y in the format 0xYYXX. Useful if you want to check for a single position.
animation_frame |  |

Variables that require a signed x,y offset. The offset is relative to the current tile. Offset 0,0 means the current tile.

name | value range | comment
--- | --- | ---
nearby_tile_slope | Which corners are raised on the given tile. | Bit 0: west corner is above the lowest corner. Bit 1: south corner is above the lowest corner. Bit 2: east corner is above the lowest corner. Bit 3: north corner is above the lowest corner. Bit 4: this tile is a steep slope (the corner opposite to the lowest corner is 2 units higher). See tile slopes for an illustration
nearby_tile_is_same_airport | 1 if the tile is part of the same airport, 0 otherwise |
nearby_tile_is_water | 1 if the tile is water, 0 otherwise |
nearby_tile_terrain_type | TILETYPE_XX | TILETYPE_NORMAL, TILETYPE_DESERT, TILETYPE_RAIN_FOREST, TILETYPE_SNOW
nearby_tile_height | 0..120 | The height of the lowest corner of the given tile.
nearby_tile_class | Tile class |
nearby_tile_animation_frame | 0..255 | Animation frame of the given tile
nearby_tile_airporttile_id | 0x00aa, 0xFFbb, 0xFFFE or 0xFFFF | 0x00aa: The tile is an airport tile that is part of this GRF, the tile id is aa. 0xFFbb: The tile is an original airport tile with id bb. 0xFFFE: The tile is an airport tile defined in another GRF. 0xFFFF: The tile is not an airport tile or it belongs to another GRF.